Module datatype
tablestg
0.4.27
Module datatype
Module Items
Enums
Type Aliases
In crate tablestg
tablestg
Module
datatype
DataType
- describes, encodes and decodes
Value
s.
Enums

Data
Type
Describes type of
Value
. Has methods for encoding value as bytes, decoding bytes to value.
Lazy
Item
Initially offset of serialised data, changes to value when accessed.
Type Aliases

MSPX
Mut Store, PageSet.
SPX
Store, PageSet.