Re-exports
pub use table::Table;pub use value::Value;pub use datatype::DataType;pub use pageset::PageSet;pub use store::Store;pub use vbuckmap::IdVKey;
Modules
- datatype
- DataType - describes, encodes and decodes Values.
- pageset
- PageSet - keeps track of changed pages that need saving.
- store
- Store - maps keys to variable size values (no size restriction) using 64 bit hash.
- table
- Table stores Values which have a specific DataType.
- value
- Generic Values.
- vbuckmap
- VBuckMap - maps keys to small variable size values using 64 bit hash. For possibly large values see Store.
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Local
- Local is for thread-local allocations.
Local has an array of free lists, one for each size class
MIN_SIZE..MAX_SIZE. Allocations larger thanMAX_SIZEbytes, or having more thanMIN_SIZEalignment, are routed toSystem. - Perm
- Perm is for non-thread-local allocations.
Perm is similar to Local, except there is a single instance per process. It implements both
AllocatorandGlobalAllocso can be used to set a Global Allocator using the#[global_allocator]attribute.