Everything is very preliminary, this crate is not yet at all stable.
Re-exports
pub use table::Table;
Modules
- datatype
- DataType - describes, encodes and decodes Values using Store.
- pageset
- PageSet - keeps track of changed pages that need saving.
- pagetree
- List of pages implemented as tree for VBuckMap.
- store
- Store - maps keys to variable size values (no size restriction) using 64 bit hash.
- table
- A Table stores Values which have a specific DataType.
- value
- Generic Values.
- vbucket
- Bucket for VBuckMap.
- vbuckmap
- VBuckMap - maps keys to small variable size values using 64 bit hash. For possibly large values see Store.
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.